# Python Social Auth - Flask

Python Social Auth is an easy to setup social authentication/registration
mechanism with support for several frameworks and auth providers.

## Description

This is the [Flask](http://flask.pocoo.org/) component of the
[python-social-auth ecosystem](https://github.com/python-social-auth/social-core),
it implements the needed functionality to integrate
[social-auth-core](https://github.com/python-social-auth/social-core)
in a Flask based project using [SQLAlchemy](http://www.sqlalchemy.org/) by
default.

## Documentation

Project documentation is available at http://python-social-auth.readthedocs.org/.

## Setup

```shell
$ pip install social-auth-app-flask-sqlalchemy
```

## Contributing

See the [CONTRIBUTING.md](CONTRIBUTING.md) document for details.

## Versioning

This project follows [Semantic Versioning 2.0.0](http://semver.org/spec/v2.0.0.html).

## License

This project follows the BSD license. See the [LICENSE](LICENSE) for details.
